@@ -19,7 +19,7 @@ void _assert(bool condition, const char *fmt, ...) {
         va_start(args, fmt);
         vfprintf(stderr, fmt, args);
         va_end(args);
-        exit(-1);
+        exit(1);
     }
 }
 
