@@ -26,11 +26,14 @@
 #include "PyType.h"
 #include "PyVar.h"
 
-static_assert(PYBIND11_VERSION_MAJOR == 2 && PYBIND11_VERSION_MINOR >= 6,
-              "Halide requires PyBind 2.6+");
+#if !defined(PYBIND11_VERSION_HEX) || PYBIND11_VERSION_HEX < 0x02060000
+#error "Halide requires PyBind 2.6+"
+#endif
 
-static_assert(PY_VERSION_HEX >= 0x03000000,
-              "We appear to be compiling against Python 2.x rather than 3.x, which is not supported.");
+// Note: This check will be redundant when PyBind 2.10 becomes the minimum version.
+#if PY_VERSION_HEX < 0x03000000
+#error "We appear to be compiling against Python 2.x rather than 3.x, which is not supported."
+#endif
 
 #ifndef HALIDE_PYBIND_MODULE_NAME
 #define HALIDE_PYBIND_MODULE_NAME halide_
