@@ -116,25 +116,23 @@ bool can_allocation_fit_on_stack(int64_t size) {
 Expr lower_int_uint_div(const Expr &a, const Expr &b, bool round_to_zero) {
     // Detect if it's a small int division
     internal_assert(a.type() == b.type());
-    const int64_t *const_int_divisor = as_const_int(b);
-    const uint64_t *const_uint_divisor = as_const_uint(b);
+    auto const_int_divisor = as_const_int(b);
+    auto const_uint_divisor = as_const_uint(b);
 
     Type t = a.type();
     internal_assert(!t.is_float())
         << "lower_int_uint_div is not meant to handle floating-point case.\n";
 
-    int shift_amount;
-    if (is_const_power_of_two_integer(b, &shift_amount) &&
-        (t.is_int() || t.is_uint())) {
+    if (auto shift_amount = is_const_power_of_two_integer(b)) {
         if (round_to_zero) {
             Expr result = a;
             // Normally a right-shift isn't right for division rounding to
             // zero. It does the wrong thing for negative values. Add a fudge so
             // that a right-shift becomes correct.
             result += (result >> (t.bits() - 1)) & (b - 1);
-            return result >> shift_amount;
+            return result >> *shift_amount;
         } else {
-            return a >> make_const(UInt(a.type().bits()), shift_amount);
+            return a >> make_const(UInt(a.type().bits()), *shift_amount);
         }
     } else if (const_int_divisor &&
                t.is_int() &&
@@ -262,15 +260,14 @@ Expr lower_int_uint_div(const Expr &a, const Expr &b, bool round_to_zero) {
 
 Expr lower_int_uint_mod(const Expr &a, const Expr &b) {
     // Detect if it's a small int modulus
-    const int64_t *const_int_divisor = as_const_int(b);
-    const uint64_t *const_uint_divisor = as_const_uint(b);
+    auto const_int_divisor = as_const_int(b);
+    auto const_uint_divisor = as_const_uint(b);
 
     Type t = a.type();
     internal_assert(!t.is_float())
         << "lower_int_uint_div is not meant to handle floating-point case.\n";
 
-    int bits;
-    if (is_const_power_of_two_integer(b, &bits)) {
+    if (is_const_power_of_two_integer(b)) {
         return a & simplify(b - 1);
     } else if (const_int_divisor &&
                t.is_int() &&
@@ -292,8 +289,9 @@ Expr lower_int_uint_mod(const Expr &a, const Expr &b) {
     }
 }
 
+namespace {
 std::pair<Expr, Expr> unsigned_long_div_mod_round_to_zero(Expr &num, const Expr &den,
-                                                          const uint64_t *upper_bound) {
+                                                          std::optional<uint64_t> upper_bound) {
     internal_assert(num.type() == den.type());
     internal_assert(num.type().is_uint());
     Type ty = num.type();
@@ -329,9 +327,10 @@ std::pair<Expr, Expr> unsigned_long_div_mod_round_to_zero(Expr &num, const Expr
     }
     return {q, r};
 }
+}  // namespace
 
 std::pair<Expr, Expr> long_div_mod_round_to_zero(const Expr &num, const Expr &den,
-                                                 const uint64_t *max_abs) {
+                                                 std::optional<uint64_t> max_abs) {
     debug(1) << "Using long div: (num: " << num << "); (den: " << den << ")\n";
     internal_assert(num.type() == den.type());
     Expr abs_num = (num.type().is_int()) ? abs(num) : num;
@@ -474,8 +473,7 @@ Expr lower_euclidean_mod(Expr a, Expr b) {
 
 Expr lower_signed_shift_left(const Expr &a, const Expr &b) {
     internal_assert(b.type().is_int());
-    const int64_t *const_int_b = as_const_int(b);
-    if (const_int_b) {
+    if (auto const_int_b = as_const_int(b)) {
         Expr val;
         const uint64_t b_unsigned = std::abs(*const_int_b);
         if (*const_int_b >= 0) {
@@ -495,8 +493,7 @@ Expr lower_signed_shift_left(const Expr &a, const Expr &b) {
 
 Expr lower_signed_shift_right(const Expr &a, const Expr &b) {
     internal_assert(b.type().is_int());
-    const int64_t *const_int_b = as_const_int(b);
-    if (const_int_b) {
+    if (auto const_int_b = as_const_int(b)) {
         Expr val;
         const uint64_t b_unsigned = std::abs(*const_int_b);
         if (*const_int_b >= 0) {
@@ -557,46 +554,51 @@ Expr lower_round_to_nearest_ties_to_even(const Expr &x) {
     return common_subexpression_elimination(a - correction);
 }
 
-bool get_md_bool(llvm::Metadata *value, bool &result) {
+namespace {
+std::optional<int64_t> get_md_int(llvm::Metadata *value) {
     if (!value) {
-        return false;
+        return std::nullopt;
     }
     llvm::ConstantAsMetadata *cam = llvm::cast<llvm::ConstantAsMetadata>(value);
     if (!cam) {
-        return false;
+        return std::nullopt;
     }
     llvm::ConstantInt *c = llvm::cast<llvm::ConstantInt>(cam->getValue());
     if (!c) {
-        return false;
+        return std::nullopt;
     }
-    result = !c->isZero();
-    return true;
+    return c->getSExtValue();
 }
 
-bool get_md_string(llvm::Metadata *value, std::string &result) {
+std::optional<bool> get_md_bool(llvm::Metadata *value) {
+    if (auto r = get_md_int(value)) {
+        return *r != 0;
+    } else {
+        return std::nullopt;
+    }
+}
+
+std::optional<std::string> get_md_string(llvm::Metadata *value) {
     if (!value) {
-        result = "";
-        return false;
+        return std::nullopt;
     }
     llvm::MDString *c = llvm::dyn_cast<llvm::MDString>(value);
     if (c) {
-        result = c->getString().str();
-        return true;
+        return c->getString().str();
     }
-    return false;
+    return std::nullopt;
 }
+}  // namespace
 
 void get_target_options(const llvm::Module &module, llvm::TargetOptions &options) {
-    bool use_soft_float_abi = false;
-    get_md_bool(module.getModuleFlag("halide_use_soft_float_abi"), use_soft_float_abi);
-    std::string mabi;
-    get_md_string(module.getModuleFlag("halide_mabi"), mabi);
-    bool use_pic = true;
-    get_md_bool(module.getModuleFlag("halide_use_pic"), use_pic);
+    bool use_soft_float_abi =
+        get_md_bool(module.getModuleFlag("halide_use_soft_float_abi")).value_or(false);
+    std::string mabi =
+        get_md_string(module.getModuleFlag("halide_mabi")).value_or(std::string{});
 
     // FIXME: can this be migrated into `set_function_attributes_from_halide_target_options()`?
-    bool per_instruction_fast_math_flags = false;
-    get_md_bool(module.getModuleFlag("halide_per_instruction_fast_math_flags"), per_instruction_fast_math_flags);
+    bool per_instruction_fast_math_flags =
+        get_md_bool(module.getModuleFlag("halide_per_instruction_fast_math_flags")).value_or(false);
 
     options = llvm::TargetOptions();
     options.AllowFPOpFusion = per_instruction_fast_math_flags ? llvm::FPOpFusion::Strict : llvm::FPOpFusion::Fast;
@@ -623,29 +625,22 @@ void clone_target_options(const llvm::Module &from, llvm::Module &to) {
 
     llvm::LLVMContext &context = to.getContext();
 
-    bool use_soft_float_abi = false;
-    if (get_md_bool(from.getModuleFlag("halide_use_soft_float_abi"), use_soft_float_abi)) {
-        to.addModuleFlag(llvm::Module::Warning, "halide_use_soft_float_abi", use_soft_float_abi ? 1 : 0);
+    // Clone bool metadata
+    for (const char *s : {"halide_use_soft_float_abi",
+                          "halide_use_pic"}) {
+        if (auto md = get_md_bool(from.getModuleFlag(s))) {
+            to.addModuleFlag(llvm::Module::Warning, s, *md ? 1 : 0);
+        }
     }
 
-    std::string mcpu_target;
-    if (get_md_string(from.getModuleFlag("halide_mcpu_target"), mcpu_target)) {
-        to.addModuleFlag(llvm::Module::Warning, "halide_mcpu_target", llvm::MDString::get(context, mcpu_target));
-    }
+    // Clone string metadata
+    for (const char *s : {"halide_mcpu_target",
+                          "halide_mcpu_tune",
+                          "halide_mattrs"}) {
 
-    std::string mcpu_tune;
-    if (get_md_string(from.getModuleFlag("halide_mcpu_tune"), mcpu_tune)) {
-        to.addModuleFlag(llvm::Module::Warning, "halide_mcpu_tune", llvm::MDString::get(context, mcpu_tune));
-    }
-
-    std::string mattrs;
-    if (get_md_string(from.getModuleFlag("halide_mattrs"), mattrs)) {
-        to.addModuleFlag(llvm::Module::Warning, "halide_mattrs", llvm::MDString::get(context, mattrs));
-    }
-
-    bool use_pic = true;
-    if (get_md_bool(from.getModuleFlag("halide_use_pic"), use_pic)) {
-        to.addModuleFlag(llvm::Module::Warning, "halide_use_pic", use_pic ? 1 : 0);
+        if (auto md = get_md_string(from.getModuleFlag(s))) {
+            to.addModuleFlag(llvm::Module::Warning, s, llvm::MDString::get(context, *md));
+        }
     }
 }
 
@@ -663,11 +658,11 @@ std::unique_ptr<llvm::TargetMachine> make_target_machine(const llvm::Module &mod
     llvm::TargetOptions options;
     get_target_options(module, options);
 
-    bool use_pic = true;
-    get_md_bool(module.getModuleFlag("halide_use_pic"), use_pic);
+    bool use_pic =
+        get_md_bool(module.getModuleFlag("halide_use_pic")).value_or(true);
 
-    bool use_large_code_model = false;
-    get_md_bool(module.getModuleFlag("halide_use_large_code_model"), use_large_code_model);
+    bool use_large_code_model =
+        get_md_bool(module.getModuleFlag("halide_use_large_code_model")).value_or(false);
 
 #if LLVM_VERSION >= 180
     const auto opt_level = llvm::CodeGenOptLevel::Aggressive;
@@ -676,10 +671,10 @@ std::unique_ptr<llvm::TargetMachine> make_target_machine(const llvm::Module &mod
 #endif
 
     // Get module mcpu_target and mattrs.
-    std::string mcpu_target;
-    get_md_string(module.getModuleFlag("halide_mcpu_target"), mcpu_target);
-    std::string mattrs;
-    get_md_string(module.getModuleFlag("halide_mattrs"), mattrs);
+    std::string mcpu_target =
+        get_md_string(module.getModuleFlag("halide_mcpu_target")).value_or(std::string{});
+    std::string mattrs =
+        get_md_string(module.getModuleFlag("halide_mattrs")).value_or(std::string{});
 
     auto *tm = llvm_target->createTargetMachine(module.getTargetTriple(),
                                                 mcpu_target,
@@ -694,11 +689,14 @@ std::unique_ptr<llvm::TargetMachine> make_target_machine(const llvm::Module &mod
 void set_function_attributes_from_halide_target_options(llvm::Function &fn) {
     llvm::Module &module = *fn.getParent();
 
-    std::string mcpu_target, mcpu_tune, mattrs, vscale_range;
-    get_md_string(module.getModuleFlag("halide_mcpu_target"), mcpu_target);
-    get_md_string(module.getModuleFlag("halide_mcpu_tune"), mcpu_tune);
-    get_md_string(module.getModuleFlag("halide_mattrs"), mattrs);
-    get_md_string(module.getModuleFlag("halide_vscale_range"), vscale_range);
+    std::string mcpu_target =
+        get_md_string(module.getModuleFlag("halide_mcpu_target")).value_or(std::string{});
+    std::string mcpu_tune =
+        get_md_string(module.getModuleFlag("halide_mcpu_tune")).value_or(std::string{});
+    std::string mattrs =
+        get_md_string(module.getModuleFlag("halide_mattrs")).value_or(std::string{});
+    int64_t vscale_range =
+        get_md_int(module.getModuleFlag("halide_effective_vscale")).value_or(0);
 
     fn.addFnAttr("target-cpu", mcpu_target);
     fn.addFnAttr("tune-cpu", mcpu_tune);
@@ -719,8 +717,9 @@ void set_function_attributes_from_halide_target_options(llvm::Function &fn) {
     fn.addFnAttr("reciprocal-estimates", "none");
 
     // If a fixed vscale is asserted, add it as an attribute on the function.
-    if (!vscale_range.empty()) {
-        fn.addFnAttr("vscale_range", vscale_range);
+    if (vscale_range != 0) {
+        fn.addFnAttr(llvm::Attribute::getWithVScaleRangeArgs(
+            module.getContext(), vscale_range, vscale_range));
     }
 }
 
@@ -728,7 +727,7 @@ void embed_bitcode(llvm::Module *M, const string &halide_command) {
     // Save llvm.compiler.used and remote it.
     SmallVector<Constant *, 2> used_array;
     SmallVector<GlobalValue *, 4> used_globals;
-    llvm::Type *used_element_type = llvm::Type::getInt8Ty(M->getContext())->getPointerTo(0);
+    llvm::Type *used_element_type = PointerType::get(llvm::Type::getInt8Ty(M->getContext()), 0);
     GlobalVariable *used = collectUsedGlobalVariables(*M, used_globals, true);
     for (auto *GV : used_globals) {
         if (GV->getName() != "llvm.embedded.module" &&
