@@ -143,9 +143,6 @@ CodeGen_RISCV::CodeGen_RISCV(const Target &t)
     user_assert(native_vector_bits() > 0) << "No vector_bits was specified for RISCV codegen; "
                                           << "this is almost certainly a mistake. You should add -rvv-vector_bits_N "
                                           << "to your Target string, where N is the SIMD width in bits (e.g. 128).";
-#if LLVM_VERSION < 170
-    user_warning << "RISCV codegen is only tested with LLVM 17.0 or later; it is unlikely to work well with earlier versions of LLVM.\n";
-#endif
 }
 
 string CodeGen_RISCV::mcpu_target() const {
@@ -349,11 +346,9 @@ bool CodeGen_RISCV::call_riscv_vector_intrinsic(const RISCVIntrinsic &intrin, co
         left_arg->getType(),
         right_arg->getType(),
     };
-#if LLVM_VERSION >= 170
     if (round_any) {
         llvm_arg_types.push_back(xlen_type);
     }
-#endif
     if (intrin.flags & AddVLArg) {
         llvm_arg_types.push_back(xlen_type);
     }
