@@ -18,7 +18,6 @@ enum class DeviceAPI {
     Default_GPU,
     CUDA,
     OpenCL,
-    OpenGLCompute,
     Metal,
     Hexagon,
     HexagonDma,
@@ -34,7 +33,6 @@ const DeviceAPI all_device_apis[] = {DeviceAPI::None,
                                      DeviceAPI::Default_GPU,
                                      DeviceAPI::CUDA,
                                      DeviceAPI::OpenCL,
-                                     DeviceAPI::OpenGLCompute,
                                      DeviceAPI::Metal,
                                      DeviceAPI::Hexagon,
                                      DeviceAPI::HexagonDma,
