@@ -110,6 +110,8 @@ struct FunctionContents {
     bool trace_loads = false, trace_stores = false, trace_realizations = false;
     std::vector<string> trace_tags;
 
+    bool no_profiling = false;
+
     bool frozen = false;
 
     void accept(IRVisitor *visitor) const {
@@ -352,6 +354,7 @@ void Function::update_with_deserialization(const std::string &name,
                                            bool trace_stores,
                                            bool trace_realizations,
                                            const std::vector<std::string> &trace_tags,
+                                           bool no_profiling,
                                            bool frozen) {
     contents->name = name;
     contents->origin_name = origin_name;
@@ -373,6 +376,7 @@ void Function::update_with_deserialization(const std::string &name,
     contents->trace_stores = trace_stores;
     contents->trace_realizations = trace_realizations;
     contents->trace_tags = trace_tags;
+    contents->no_profiling = no_profiling;
     contents->frozen = frozen;
 }
 
@@ -487,8 +491,10 @@ ExternFuncArgument deep_copy_extern_func_argument_helper(const ExternFuncArgumen
 }  // namespace
 
 void Function::deep_copy(const FunctionPtr &copy, DeepCopyMap &copied_map) const {
-    internal_assert(copy.defined() && contents.defined())
-        << "Cannot deep-copy undefined Function\n";
+    internal_assert(copy.defined())
+        << "Cannot deep-copy to undefined Function\n";
+    internal_assert(contents.defined())
+        << "Cannot deep-copy from undefined Function\n";
 
     // Add reference to this Function's deep-copy to the map in case of
     // self-reference, e.g. self-reference in an Definition.
@@ -509,6 +515,7 @@ void Function::deep_copy(const FunctionPtr &copy, DeepCopyMap &copied_map) const
     copy->trace_stores = contents->trace_stores;
     copy->trace_realizations = contents->trace_realizations;
     copy->trace_tags = contents->trace_tags;
+    copy->no_profiling = contents->no_profiling;
     copy->frozen = contents->frozen;
     copy->output_buffers = contents->output_buffers;
     copy->func_schedule = contents->func_schedule.deep_copy(copied_map);
@@ -671,7 +678,7 @@ void Function::create_output_buffers(const std::vector<Type> &types, int dims) c
     }
 }
 
-void Function::define_update(const vector<Expr> &_args, vector<Expr> values) {
+void Function::define_update(const vector<Expr> &_args, vector<Expr> values, const ReductionDomain &rdom) {
     int update_idx = static_cast<int>(contents->updates.size());
 
     user_assert(!name().empty())
@@ -760,6 +767,23 @@ void Function::define_update(const vector<Expr> &_args, vector<Expr> values) {
     for (const auto &value : values) {
         value.accept(&check);
     }
+    if (!check.reduction_domain.defined()) {
+        // Use the provided one
+        check.reduction_domain = rdom;
+    } else if (rdom.defined()) {
+        // This is an internal error because the ability to pass an explicit
+        // RDom is not exposed to the front-end. At the time of writing this is
+        // only used by rfactor.
+        internal_assert(rdom.same_as(check.reduction_domain))
+            << "In update definition " << update_idx << " of Func \"" << name() << "\":\n"
+            << "Explicit reduction domain passed to Function::define_update, "
+            << "but another reduction domain was referred to by the args or values.\n"
+            << "Explicit reduction domain passed:\n"
+            << RDom(rdom) << "\n"
+            << "Found reduction domain:\n"
+            << RDom(check.reduction_domain) << "\n";
+    }
+
     if (check.reduction_domain.defined()) {
         check.unbound_reduction_vars_ok = true;
         check.reduction_domain.predicate().accept(&check);
@@ -922,13 +946,14 @@ void Function::define_extern(const std::string &function_name,
     contents->func_schedule.storage_dims().clear();
     contents->init_def.schedule().dims().clear();
     for (size_t i = 0; i < args.size(); i++) {
-        contents->func_schedule.storage_dims().push_back(StorageDim{arg_names[i]});
-        contents->init_def.schedule().dims().push_back(
-            Dim{arg_names[i], ForType::Extern, DeviceAPI::None, DimType::PureVar});
+        StorageDim sd = {arg_names[i]};
+        contents->func_schedule.storage_dims().push_back(sd);
+        Dim d = {arg_names[i], ForType::Extern, DeviceAPI::None, DimType::PureVar};
+        contents->init_def.schedule().dims().push_back(d);
     }
     // Add the dummy outermost dim
-    contents->init_def.schedule().dims().push_back(
-        Dim{Var::outermost().name(), ForType::Serial, DeviceAPI::None, DimType::PureVar});
+    Dim d = {Var::outermost().name(), ForType::Serial, DeviceAPI::None, DimType::PureVar};
+    contents->init_def.schedule().dims().push_back(d);
 }
 
 void Function::accept(IRVisitor *visitor) const {
@@ -1138,10 +1163,6 @@ const std::vector<std::string> &Function::get_trace_tags() const {
     return contents->trace_tags;
 }
 
-void Function::freeze() {
-    contents->frozen = true;
-}
-
 void Function::lock_loop_levels() {
     auto &schedule = contents->func_schedule;
     schedule.compute_level().lock();
@@ -1165,6 +1186,16 @@ void Function::lock_loop_levels() {
     }
 }
 
+void Function::do_not_profile() {
+    contents->no_profiling = true;
+}
+bool Function::should_not_profile() const {
+    return contents->no_profiling;
+}
+
+void Function::freeze() {
+    contents->frozen = true;
+}
 bool Function::frozen() const {
     return contents->frozen;
 }
