@@ -168,9 +168,7 @@ class NormalizeDimensionality : public IRMutator {
         if (op->for_type == ForType::GPUThread ||
             op->for_type == ForType::GPULane) {
             depth++;
-            if (depth > max_depth) {
-                max_depth = depth;
-            }
+            max_depth = std::max(max_depth, depth);
             Stmt stmt = IRMutator::visit(op);
             depth--;
             return stmt;
@@ -656,8 +654,8 @@ private:
                     const auto &candidate_group = mem_allocs[free_spaces[i]];
                     Expr size = alloc_size * alloc.type.bytes();
                     Expr dist = candidate_group.max_size * candidate_group.widest_type.bytes() - size;
-                    const int64_t *current_diff = as_const_int(simplify(dist));
-                    internal_assert(current_diff != nullptr);
+                    auto current_diff = as_const_int(simplify(dist));
+                    internal_assert(current_diff);
                     int64_t abs_diff = std::abs(*current_diff);
                     if ((free_idx == -1) || (abs_diff < diff)) {
                         diff = abs_diff;
