@@ -9,8 +9,10 @@
 
 #include <cmath>
 #include <map>
+#include <optional>
 
 #include "Expr.h"
+#include "Target.h"
 #include "Tuple.h"
 
 namespace Halide {
@@ -26,21 +28,25 @@ bool is_const(const Expr &e);
 bool is_const(const Expr &e, int64_t v);
 
 /** If an expression is an IntImm or a Broadcast of an IntImm, return
- * a pointer to its value. Otherwise returns nullptr. */
-const int64_t *as_const_int(const Expr &e);
+ * a its value. Otherwise returns std::nullopt. */
+std::optional<int64_t> as_const_int(const Expr &e);
 
 /** If an expression is a UIntImm or a Broadcast of a UIntImm, return
- * a pointer to its value. Otherwise returns nullptr. */
-const uint64_t *as_const_uint(const Expr &e);
+ * its value. Otherwise returns std::nullopt. */
+std::optional<uint64_t> as_const_uint(const Expr &e);
 
 /** If an expression is a FloatImm or a Broadcast of a FloatImm,
- * return a pointer to its value. Otherwise returns nullptr. */
-const double *as_const_float(const Expr &e);
+ * return its value. Otherwise returns std::nullopt. */
+std::optional<double> as_const_float(const Expr &e);
 
-/** Is the expression a constant integer power of two. Also returns
- * log base two of the expression if it is. Only returns true for
- * integer types. */
-bool is_const_power_of_two_integer(const Expr &e, int *bits);
+/** Is the expression a constant integer power of two. Returns log base two of
+ * the expression if it is, or std::nullopt if not. Also returns std::nullopt
+ * for non-integer types. */
+// @{
+std::optional<int> is_const_power_of_two_integer(const Expr &e);
+std::optional<int> is_const_power_of_two_integer(uint64_t);
+std::optional<int> is_const_power_of_two_integer(int64_t);
+// @}
 
 /** Is the expression a const (as defined by is_const), and also
  * strictly greater than zero (in all lanes, if a vector expression) */
@@ -1689,6 +1695,51 @@ Expr rounding_mul_shift_right(Expr a, Expr b, Expr q);
 Expr rounding_mul_shift_right(Expr a, Expr b, int q);
 //@}
 
+/** Return a boolean Expr for the corresponding field of the Target
+ * being used during lowering; they can be useful in writing library
+ * code without having to plumb a Target through call sites, so that you
+ * can do things like
+ \code
+    Expr e = select(target_arch_is(Target::ARM), something, something_else);
+ \endcode
+ * Note that this doesn't do any checking at runtime to verify that the Target
+ * is valid for the current hardware configuration.
+ */
+//@{
+Expr target_arch_is(Target::Arch arch);
+Expr target_os_is(Target::OS os);
+Expr target_has_feature(Target::Feature feat);
+//@}
+
+/** Return the bit width of the Target used during lowering; this can be useful
+ * in writing library code without having to plumb a Target through call sites,
+ * so that you can do things like
+ \code
+    Expr e = select(target_bits() == 32, something, something_else);
+ \endcode
+ * Note that this doesn't do any checking at runtime to verify that the Target
+ * is valid for the current hardware configuration.
+ */
+Expr target_bits();
+
+/** Return the natural vector width for the given Type for the Target
+ * being used during lowering; this can be useful in writing library
+ * code without having to plumb a Target through call sites, so that you
+ * can do things like
+ \code
+    f.vectorize(x, target_natural_vector_size(Float(32)));
+ \endcode
+ * Note that this doesn't do any checking at runtime to verify that the Target
+ * is valid for the current hardware configuration.
+ */
+//@{
+Expr target_natural_vector_size(Type t);
+template<typename data_t>
+Expr target_natural_vector_size() {
+    return target_natural_vector_size(type_of<data_t>());
+}
+//@}
+
 }  // namespace Halide
 
 #endif
