@@ -361,7 +361,6 @@ void JITModule::compile_module(std::unique_ptr<llvm::Module> m, const string &fu
         for (auto const &iter : module.exports()) {
             orc::SymbolStringPtr name = symbolStringPool->intern(iter.first);
             orc::SymbolStringPtr _name = symbolStringPool->intern("_" + iter.first);
-#if LLVM_VERSION >= 170
             auto symbol = llvm::orc::ExecutorAddr::fromPtr(iter.second.address);
             if (!newSymbols.count(name)) {
                 newSymbols.insert({name, {symbol, JITSymbolFlags::Exported}});
@@ -369,15 +368,6 @@ void JITModule::compile_module(std::unique_ptr<llvm::Module> m, const string &fu
             if (!newSymbols.count(_name)) {
                 newSymbols.insert({_name, {symbol, JITSymbolFlags::Exported}});
             }
-#else
-            auto symbol = llvm::JITEvaluatedSymbol::fromPointer(iter.second.address);
-            if (!newSymbols.count(name)) {
-                newSymbols.insert({name, symbol});
-            }
-            if (!newSymbols.count(_name)) {
-                newSymbols.insert({_name, symbol});
-            }
-#endif
         }
     }
     err = JIT->getMainJITDylib().define(orc::absoluteSymbols(std::move(newSymbols)));
@@ -539,6 +529,24 @@ void JITModule::reuse_device_allocations(bool b) const {
     }
 }
 
+int JITModule::get_num_threads() const {
+    std::map<std::string, Symbol>::const_iterator f =
+        exports().find("halide_get_num_threads");
+    if (f != exports().end()) {
+        return (reinterpret_bits<int (*)()>(f->second.address))();
+    }
+    return 1;
+}
+
+int JITModule::set_num_threads(int n) const {
+    std::map<std::string, Symbol>::const_iterator f =
+        exports().find("halide_set_num_threads");
+    if (f != exports().end()) {
+        return (reinterpret_bits<int (*)(int)>(f->second.address))(n);
+    }
+    return 1;
+}
+
 bool JITModule::compiled() const {
     return jit_module->JIT != nullptr;
 }
@@ -596,7 +604,7 @@ void print_handler(JITUserContext *context, const char *msg) {
     if (context && context->handlers.custom_print) {
         context->handlers.custom_print(context, msg);
     } else {
-        return active_handlers.custom_print(context, msg);
+        active_handlers.custom_print(context, msg);
     }
 }
 
@@ -1085,6 +1093,16 @@ void JITSharedRuntime::reuse_device_allocations(bool b) {
     shared_runtimes(MainShared).reuse_device_allocations(b);
 }
 
+int JITSharedRuntime::get_num_threads() {
+    std::lock_guard<std::mutex> lock(shared_runtimes_mutex);
+    return shared_runtimes(MainShared).get_num_threads();
+}
+
+int JITSharedRuntime::set_num_threads(int n) {
+    std::lock_guard<std::mutex> lock(shared_runtimes_mutex);
+    return shared_runtimes(MainShared).set_num_threads(n);
+}
+
 JITCache::JITCache(Target jit_target,
                    std::vector<Argument> arguments,
                    std::map<std::string, JITExtern> jit_externs,
