@@ -1,10 +1,10 @@
 #ifndef HALIDE_LLVM_HEADERS_H
 #define HALIDE_LLVM_HEADERS_H
 
-#if LLVM_VERSION >= 160
+#if LLVM_VERSION >= 170
 // We're good to go
 #else
-#error "Compiling Halide requires LLVM 16.0 or newer"
+#error "Compiling Halide requires LLVM 17.0 or newer"
 #endif
 
 // No msvc warnings from llvm headers please
@@ -22,18 +22,13 @@
 
 #if WITH_WABT || WITH_V8
 #include <lld/Common/Driver.h>
-#if LLVM_VERSION >= 170
 #include <lld/Common/ErrorHandler.h>
 #endif
-#endif
 #include <llvm/ADT/APFloat.h>
 #include <llvm/ADT/ArrayRef.h>
 #include <llvm/ADT/SmallVector.h>
 #include <llvm/ADT/StringMap.h>
 #include <llvm/ADT/StringRef.h>
-#if LLVM_VERSION < 170
-#include <llvm/ADT/Triple.h>
-#endif
 #include <llvm/ADT/Twine.h>
 #include <llvm/Analysis/AliasAnalysis.h>
 #include <llvm/Analysis/TargetLibraryInfo.h>
@@ -86,16 +81,13 @@
 #include <llvm/Support/raw_ostream.h>
 #include <llvm/Target/TargetMachine.h>
 #include <llvm/Target/TargetOptions.h>
-#if LLVM_VERSION >= 170
 #include <llvm/TargetParser/Triple.h>
-#endif
 #include <llvm/Transforms/IPO.h>
 #include <llvm/Transforms/IPO/AlwaysInliner.h>
 #include <llvm/Transforms/IPO/Inliner.h>
-#if LLVM_VERSION < 170
-#include <llvm/Transforms/IPO/PassManagerBuilder.h>
-#endif
+#if LLVM_VERSION < 200
 #include <llvm/Transforms/Instrumentation.h>
+#endif
 #include <llvm/Transforms/Instrumentation/AddressSanitizer.h>
 #include <llvm/Transforms/Instrumentation/SanitizerCoverage.h>
 #include <llvm/Transforms/Instrumentation/ThreadSanitizer.h>
