@@ -3,49 +3,16 @@
 namespace Halide {
 namespace Internal {
 
-Expr Simplify::visit(const Mul *op, ExprInfo *bounds) {
-    ExprInfo a_bounds, b_bounds;
-    Expr a = mutate(op->a, &a_bounds);
-    Expr b = mutate(op->b, &b_bounds);
+Expr Simplify::visit(const Mul *op, ExprInfo *info) {
+    ExprInfo a_info, b_info;
+    Expr a = mutate(op->a, &a_info);
+    Expr b = mutate(op->b, &b_info);
 
-    if (bounds && no_overflow_int(op->type)) {
-        bool a_positive = a_bounds.min_defined && a_bounds.min > 0;
-        bool b_positive = b_bounds.min_defined && b_bounds.min > 0;
-        bool a_bounded = a_bounds.min_defined && a_bounds.max_defined;
-        bool b_bounded = b_bounds.min_defined && b_bounds.max_defined;
-
-        if (a_bounded && b_bounded) {
-            bounds->min_defined = bounds->max_defined = true;
-            int64_t v1 = saturating_mul(a_bounds.min, b_bounds.min);
-            int64_t v2 = saturating_mul(a_bounds.min, b_bounds.max);
-            int64_t v3 = saturating_mul(a_bounds.max, b_bounds.min);
-            int64_t v4 = saturating_mul(a_bounds.max, b_bounds.max);
-            bounds->min = std::min(std::min(v1, v2), std::min(v3, v4));
-            bounds->max = std::max(std::max(v1, v2), std::max(v3, v4));
-        } else if ((a_bounds.max_defined && b_bounded && b_positive) ||
-                   (b_bounds.max_defined && a_bounded && a_positive)) {
-            bounds->max_defined = true;
-            bounds->max = saturating_mul(a_bounds.max, b_bounds.max);
-        } else if ((a_bounds.min_defined && b_bounded && b_positive) ||
-                   (b_bounds.min_defined && a_bounded && a_positive)) {
-            bounds->min_defined = true;
-            bounds->min = saturating_mul(a_bounds.min, b_bounds.min);
-        }
-
-        if (bounds->max_defined && bounds->max == INT64_MAX) {
-            // Assume it saturated to avoid overflow. This gives up a
-            // single representable value at the top end of the range
-            // to represent infinity.
-            bounds->max_defined = false;
-            bounds->max = 0;
-        }
-        if (bounds->min_defined && bounds->min == INT64_MIN) {
-            bounds->min_defined = false;
-            bounds->min = 0;
-        }
-
-        bounds->alignment = a_bounds.alignment * b_bounds.alignment;
-        bounds->trim_bounds_using_alignment();
+    if (info) {
+        info->bounds = a_info.bounds * b_info.bounds;
+        info->alignment = a_info.alignment * b_info.alignment;
+        info->trim_bounds_using_alignment();
+        info->cast_to(op->type);
     }
 
     if (may_simplify(op->type)) {
@@ -53,7 +20,7 @@ Expr Simplify::visit(const Mul *op, ExprInfo *bounds) {
         // Order commutative operations by node type
         if (should_commute(a, b)) {
             std::swap(a, b);
-            std::swap(a_bounds, b_bounds);
+            std::swap(a_info, b_info);
         }
 
         auto rewrite = IRMatcher::rewriter(IRMatcher::mul(a, b), op->type);
@@ -103,7 +70,7 @@ Expr Simplify::visit(const Mul *op, ExprInfo *bounds) {
             rewrite(slice(x, c0, c1, c2) * (z * slice(y, c0, c1, c2)), slice(x * y, c0, c1, c2) * z, c2 > 1 && lanes_of(x) == lanes_of(y)) ||
 
             false) {
-            return mutate(rewrite.result, bounds);
+            return mutate(rewrite.result, info);
         }
     }
 
