@@ -541,6 +541,7 @@ Target::Feature get_host_vulkan_capability(Target t) {
     return cap;
 }
 
+// Keep this list in sync in HalideGeneratorHelpers.cmake
 const std::map<std::string, Target::OS> os_name_map = {
     {"os_unknown", Target::OSUnknown},
     {"linux", Target::Linux},
@@ -562,6 +563,7 @@ bool lookup_os(const std::string &tok, Target::OS &result) {
     return false;
 }
 
+// Keep this list in sync in HalideGeneratorHelpers.cmake
 const std::map<std::string, Target::Arch> arch_name_map = {
     {"arch_unknown", Target::ArchUnknown},
     {"x86", Target::X86},
@@ -688,7 +690,16 @@ const std::map<std::string, Target::Feature> feature_name_map = {
     {"arm_fp16", Target::ARMFp16},
     {"llvm_large_code_model", Target::LLVMLargeCodeModel},
     {"rvv", Target::RVV},
+    {"armv8a", Target::ARMv8a},
     {"armv81a", Target::ARMv81a},
+    {"armv82a", Target::ARMv82a},
+    {"armv83a", Target::ARMv83a},
+    {"armv84a", Target::ARMv84a},
+    {"armv85a", Target::ARMv85a},
+    {"armv86a", Target::ARMv86a},
+    {"armv87a", Target::ARMv87a},
+    {"armv88a", Target::ARMv88a},
+    {"armv89a", Target::ARMv89a},
     {"sanitizer_coverage", Target::SanitizerCoverage},
     {"profile_by_timer", Target::ProfileByTimer},
     {"spirv", Target::SPIRV},
@@ -1258,6 +1269,40 @@ int Target::get_vulkan_capability_lower_bound() const {
     return 10;
 }
 
+int Target::get_arm_v8_lower_bound() const {
+    if (has_feature(Target::ARMv8a)) {
+        return 80;
+    }
+    if (has_feature(Target::ARMv81a)) {
+        return 81;
+    }
+    if (has_feature(Target::ARMv82a)) {
+        return 82;
+    }
+    if (has_feature(Target::ARMv83a)) {
+        return 83;
+    }
+    if (has_feature(Target::ARMv84a)) {
+        return 84;
+    }
+    if (has_feature(Target::ARMv85a)) {
+        return 85;
+    }
+    if (has_feature(Target::ARMv86a)) {
+        return 86;
+    }
+    if (has_feature(Target::ARMv87a)) {
+        return 87;
+    }
+    if (has_feature(Target::ARMv88a)) {
+        return 88;
+    }
+    if (has_feature(Target::ARMv89a)) {
+        return 89;
+    }
+    return -1;
+}
+
 bool Target::supports_type(const Type &t) const {
     if (t.bits() == 64) {
         if (t.is_float()) {
@@ -1461,7 +1506,7 @@ bool Target::get_runtime_compatible_target(const Target &other, Target &result)
     // (c) must match across both targets; it is an error if one target has the feature and the other doesn't
 
     // clang-format off
-    const std::array<Feature, 23> union_features = {{
+    const std::array<Feature, 33> union_features = {{
         // These are true union features.
         CUDA,
         D3D12Compute,
@@ -1482,20 +1527,32 @@ bool Target::get_runtime_compatible_target(const Target &other, Target &result)
         CUDACapability75,
         CUDACapability80,
         CUDACapability86,
+
         HVX_v62,
         HVX_v65,
         HVX_v66,
         HVX_v68,
+
         VulkanV10,
         VulkanV12,
         VulkanV13,
+
+        ARMv8a,
+        ARMv81a,
+        ARMv82a,
+        ARMv83a,
+        ARMv84a,
+        ARMv85a,
+        ARMv86a,
+        ARMv87a,
+        ARMv88a,
+        ARMv89a,
     }};
     // clang-format on
 
     // clang-format off
-    const std::array<Feature, 15> intersection_features = {{
+    const std::array<Feature, 14> intersection_features = {{
         ARMv7s,
-        ARMv81a,
         AVX,
         AVX2,
         AVX512,
@@ -1513,7 +1570,7 @@ bool Target::get_runtime_compatible_target(const Target &other, Target &result)
     // clang-format on
 
     // clang-format off
-    const std::array<Feature, 10> matching_features = {{
+    const std::array<Feature, 9> matching_features = {{
         ASAN,
         Debug,
         HexagonDma,
@@ -1634,6 +1691,43 @@ bool Target::get_runtime_compatible_target(const Target &other, Target &result)
         output.features.reset(HVX_v68);
     }
 
+    // Pick tight lower bound for ARM capability. Use fall-through to clear redundant features
+    int arm_v8_a = get_arm_v8_lower_bound();
+    int arm_v8_b = other.get_arm_v8_lower_bound();
+
+    // Same trick as above for CUDA
+    int arm_v8_capability = (int)std::min((unsigned)arm_v8_a, (unsigned)arm_v8_b);
+    if (arm_v8_capability < 80) {
+        output.features.reset(ARMv8a);
+    }
+    if (arm_v8_capability < 81) {
+        output.features.reset(ARMv81a);
+    }
+    if (arm_v8_capability < 82) {
+        output.features.reset(ARMv82a);
+    }
+    if (arm_v8_capability < 83) {
+        output.features.reset(ARMv83a);
+    }
+    if (arm_v8_capability < 84) {
+        output.features.reset(ARMv84a);
+    }
+    if (arm_v8_capability < 85) {
+        output.features.reset(ARMv85a);
+    }
+    if (arm_v8_capability < 86) {
+        output.features.reset(ARMv86a);
+    }
+    if (arm_v8_capability < 87) {
+        output.features.reset(ARMv87a);
+    }
+    if (arm_v8_capability < 88) {
+        output.features.reset(ARMv88a);
+    }
+    if (arm_v8_capability < 89) {
+        output.features.reset(ARMv89a);
+    }
+
     result = output;
     return true;
 }
