@@ -7,7 +7,6 @@
 #include "Util.h"
 #include "Debug.h"
 #include "Error.h"
-#include "Introspection.h"
 #include <atomic>
 #include <chrono>
 #include <fstream>
@@ -273,22 +272,6 @@ string replace_all(const string &str, const string &find, const string &replace)
     return result;
 }
 
-string make_entity_name(void *stack_ptr, const string &type, char prefix) {
-    string name = Introspection::get_variable_name(stack_ptr, type);
-
-    if (name.empty()) {
-        return unique_name(prefix);
-    } else {
-        // Halide names may not contain '.'
-        for (char &c : name) {
-            if (c == '.') {
-                c = ':';
-            }
-        }
-        return unique_name(name);
-    }
-}
-
 std::vector<std::string> split_string(const std::string &source, const std::string &delim) {
     std::vector<std::string> elements;
     size_t start = 0;
@@ -619,7 +602,7 @@ struct TickStackEntry {
 
 namespace {
 
-vector<TickStackEntry> tick_stack;
+thread_local vector<TickStackEntry> tick_stack;
 
 }  // namespace
 
@@ -876,7 +859,14 @@ void run_with_large_stack(const std::function<void()> &action) {
 // Portable bit-counting methods
 int popcount64(uint64_t x) {
 #ifdef _MSC_VER
-#if defined(_WIN64)
+#if defined(_M_ARM) || defined(_M_ARM64) || defined(_M_ARM64_EC)
+    int popcnt = 0;
+    while (x) {
+        x &= x - 1;
+        popcnt++;
+    }
+    return popcnt;
+#elif defined(_WIN64)
     return __popcnt64(x);
 #else
     return __popcnt((uint32_t)(x >> 32)) + __popcnt((uint32_t)(x & 0xffffffff));
