@@ -40,8 +40,8 @@ std::vector<int> get_int_bounds(const Box &bounds) {
         const Interval &interval = bounds[i];
         Expr extent = simplify(interval.max - interval.min + 1);
         extent = simplify(substitute_var_estimates(extent));
-        const int64_t *extent_int = as_const_int(extent);
-        user_assert(extent_int != nullptr)
+        auto extent_int = as_const_int(extent);
+        user_assert(extent_int)
             << "extent:" << extent << " is not constant.\n";
         int_bounds.push_back(*extent_int);
     }
@@ -53,8 +53,8 @@ std::vector<int> get_rvar_bounds(const std::vector<ReductionVariable> &rvars) {
     rvar_bounds.reserve(rvars.size());
     for (const auto &rvar : rvars) {
         Expr extent = simplify(substitute_var_estimates(rvar.extent));
-        const int64_t *extent_int = as_const_int(extent);
-        user_assert(extent_int != nullptr)
+        auto extent_int = as_const_int(extent);
+        user_assert(extent_int)
             << "extent:" << extent << " is not constant.\n";
         rvar_bounds.push_back(*extent_int);
     }
@@ -737,7 +737,7 @@ void apply_schedule(const GradientAutoschedulerParams &params,
         pure_arg_bounds.reserve(update_args.size());
         int parallelism = 1;
         for (int arg_id = 0; arg_id < (int)update_args.size(); arg_id++) {
-            Expr arg = update_args[arg_id];
+            const Expr &arg = update_args[arg_id];
             const Variable *var = arg.as<Variable>();
             if (var != nullptr &&
                 !var->param.defined() &&
@@ -819,8 +819,6 @@ void apply_schedule(const GradientAutoschedulerParams &params,
     schedule_source << ";\n";
 }
 
-}  // namespace
-
 void generate_schedule(const std::vector<Function> &outputs,
                        const Target &target,
                        const GradientAutoschedulerParams &params,
@@ -910,11 +908,11 @@ void generate_schedule(const std::vector<Function> &outputs,
 
     std::ostringstream schedule_source;
     // Traverse from the consumers to the producers
-    for (auto it = order.rbegin(); it != order.rend(); it++) {
-        Func func(env[*it]);
-        debug(1) << "[gradient_autoscheduler] Processing function:" << *it << "\n";
+    for (const auto &func_name : reverse_view(order)) {
+        Func func(env[func_name]);
+        debug(1) << "[gradient_autoscheduler] Processing function:" << func_name << "\n";
         // Get the bounds in integer constant by substitute all the parameters' estimates.
-        Box bounds = func_bounds[*it];
+        Box bounds = func_bounds[func_name];
         std::vector<int> int_bounds = get_int_bounds(bounds);
         // Scheduling pure definition
         apply_schedule(params, target, func, -1, int_bounds, target.has_gpu_feature(), schedule_source);
@@ -950,6 +948,7 @@ struct Li2018 {
 
 REGISTER_AUTOSCHEDULER(Li2018)
 
+}  // namespace
 }  // namespace Autoscheduler
 }  // namespace Internal
 }  // namespace Halide
