@@ -21,12 +21,12 @@ void my_error_handler(JITUserContext *u, const char *msg) {
     // hence the abbreviation to "err".
     if (!strstr(msg, "OpenCL API not found")) {
         fprintf(stderr, "Saw unexpected err: %s\n", msg);
-        exit(-1);
+        exit(1);
     }
     printf("Saw expected err: %s\n", msg);
     if (load_library_calls == 0 || get_library_symbol_calls == 0) {
         fprintf(stderr, "Should have seen load_library and get_library_symbol calls!\n");
-        exit(-1);
+        exit(1);
     }
     printf("Success!\n");
     exit(0);
@@ -34,14 +34,14 @@ void my_error_handler(JITUserContext *u, const char *msg) {
 
 void *my_get_symbol_impl(const char *name) {
     fprintf(stderr, "Saw unexpected call: get_symbol(%s)\n", name);
-    exit(-1);
+    exit(1);
 }
 
 void *my_load_library_impl(const char *name) {
     load_library_calls++;
     if (!strstr(name, "OpenCL") && !strstr(name, "opencl")) {
         fprintf(stderr, "Saw unexpected call: load_library(%s)\n", name);
-        exit(-1);
+        exit(1);
     }
     printf("Saw load_library: %s\n", name);
     return nullptr;
@@ -51,7 +51,7 @@ void *my_get_library_symbol_impl(void *lib, const char *name) {
     get_library_symbol_calls++;
     if (lib != nullptr || strcmp(name, "clGetPlatformIDs") != 0) {
         fprintf(stderr, "Saw unexpected call: get_library_symbol(%p, %s)\n", lib, name);
-        exit(-1);
+        exit(1);
     }
     printf("Saw get_library_symbol: %s\n", name);
     return nullptr;
@@ -89,5 +89,5 @@ int main(int argc, char **argv) {
     Buffer<int32_t> out = f.realize({64, 64}, target);
 
     fprintf(stderr, "Should not get here.\n");
-    return -1;
+    return 1;
 }
