@@ -64,7 +64,7 @@ int main(int argc, char **argv) {
 
     if (!error_occurred) {
         printf("There should have been an error\n");
-        return -1;
+        return 1;
     }
 
     printf("Success!\n");
