@@ -19,7 +19,7 @@ int main(int argc, char **argv) {
     for (int i = 0; i < 16; i++) {
         if (im(i) != i * 3) {
             printf("im(%d) = %d\n", i, im(i));
-            return -1;
+            return 1;
         }
     }
 
