@@ -22,7 +22,7 @@ int main(int argc, char **argv) {
             for (int y = 0; y < 8; y++) {
                 if (im(x, y) != (x - 1) * y + (x + 1) * y) {
                     printf("im(%d, %d) = %d\n", x, y, im(x, y));
-                    return -1;
+                    return 1;
                 }
             }
         }
