@@ -2,14 +2,14 @@
 #include <memory>
 #include <stdio.h>
 
+using namespace Halide;
+
 int error_occurred = false;
-void halide_error(void *ctx, const char *msg) {
+void halide_error(JITUserContext *ctx, const char *msg) {
     printf("Expected: %s\n", msg);
     error_occurred = true;
 }
 
-using namespace Halide;
-
 int main(int argc, char **argv) {
     Param<int> extent;
     Var x, y, z, w;
@@ -20,7 +20,7 @@ int main(int argc, char **argv) {
 
     Func grand_total;
     grand_total() = cast<uint8_t>(sum(big(r.x, r.y, r.z, r.w)));
-    grand_total.set_error_handler(&halide_error);
+    grand_total.jit_handlers().custom_error = halide_error;
 
     Target t = get_jit_target_from_environment();
     t.set_feature(Target::LargeBuffers);
