@@ -25,7 +25,7 @@ int intermediate_bound_depend_on_output_trace(JITUserContext *user_context, cons
                 printf("Bounds on store of g were supposed to be x < y and x=[0, 99] and y=[0, 99]\n"
                        "Instead they are: %d %d\n",
                        e->coordinates[0], e->coordinates[1]);
-                exit(-1);
+                exit(1);
             }
             niters++;
         }
@@ -47,7 +47,7 @@ int func_call_bound_trace(JITUserContext *user_context, const halide_trace_event
                 printf("Bounds on store of g were supposed to be x=[10, 109]\n"
                        "Instead it is: %d\n",
                        e->coordinates[0]);
-                exit(-1);
+                exit(1);
             }
             niters++;
         }
@@ -70,7 +70,7 @@ int box_bound_trace(JITUserContext *user_context, const halide_trace_event_t *e)
                 printf("Bounds on store of g were supposed to be x < y and x=[0, 99] and y=[0, 99]\n"
                        "Instead they are: %d %d\n",
                        e->coordinates[0], e->coordinates[1]);
-                exit(-1);
+                exit(1);
             }
             niters++;
         }
@@ -100,7 +100,7 @@ int equality_inequality_bound_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -133,7 +133,7 @@ int split_fuse_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -162,7 +162,7 @@ int free_variable_bound_test(int index) {
                 if (im(x, y, z) != correct) {
                     printf("im(%d, %d, %d) = %d instead of %d\n",
                            x, y, z, im(x, y, z), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -205,14 +205,14 @@ int func_call_inside_bound_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
     if (niters_expected != niters) {
         printf("func_call_inside_bound_test : Expect niters on g to be %d but got %d instead\n",
                niters_expected, niters);
-        return -1;
+        return 1;
     }
     return 0;
 }
@@ -244,7 +244,7 @@ int func_call_inside_bound_inline_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -292,14 +292,14 @@ int two_linear_bounds_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
     if (niters_expected != niters) {
         printf("two_linear_bounds_test : Expect niters on g to be %d but got %d instead\n",
                niters_expected, niters);
-        return -1;
+        return 1;
     }
     return 0;
 }
@@ -339,7 +339,7 @@ int circle_bound_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -384,14 +384,14 @@ int intermediate_computed_if_param_test(int index) {
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n",
                            x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
         if (niters_expected != niters) {
             printf("intermediate_computed_if_param_test : Expect niters on g to be %d but got %d instead\n",
                    niters_expected, niters);
-            return -1;
+            return 1;
         }
     }
 
@@ -408,14 +408,14 @@ int intermediate_computed_if_param_test(int index) {
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n",
                            x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
         if (niters_expected != niters) {
             printf("intermediate_computed_if_param_test : Expect niters on g to be %d but got %d instead\n",
                    niters_expected, niters);
-            return -1;
+            return 1;
         }
     }
     return 0;
@@ -458,14 +458,14 @@ int intermediate_bound_depend_on_output_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
     if (niters_expected != niters) {
         printf("intermediate_bound_depend_on_output_test: Expect niters on g to be %d but got %d instead\n",
                niters_expected, niters);
-        return -1;
+        return 1;
     }
     return 0;
 }
@@ -510,7 +510,7 @@ int tile_intermediate_bound_depend_on_output_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -518,7 +518,7 @@ int tile_intermediate_bound_depend_on_output_test(int index) {
     if (niters_expected != niters) {
         printf("intermediate_bound_depend_on_output_test: Expect niters on g to be %d but got %d instead\n",
                niters_expected, niters);
-        return -1;
+        return 1;
     }
     return 0;
 }
@@ -551,7 +551,7 @@ int self_reference_bound_test(int index) {
             if (im1(x, y) != correct) {
                 printf("im1(%d, %d) = %d instead of %d\n",
                        x, y, im1(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -566,7 +566,7 @@ int self_reference_bound_test(int index) {
             if (im2(x, y) != correct) {
                 printf("im2(%d, %d) = %d instead of %d\n",
                        x, y, im2(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -602,13 +602,13 @@ int random_float_bound_test(int index) {
             if (im1(x, y) != correct) {
                 printf("im1(%d, %d) = %d instead of %d\n",
                        x, y, im1(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
     if (!(19000 <= n_true && n_true <= 21000)) {
         printf("Expected n_true to be between 19000 and 21000; got %d instead\n", n_true);
-        return -1;
+        return 1;
     }
     return 0;
 }
@@ -637,13 +637,13 @@ int newton_method_test() {
             int num_iters = r1(i);
             if (num_iters == max_iters) {
                 printf("Newton's method didn't converge!\n");
-                return -1;
+                return 1;
             }
             if (std::abs(prod - 1) > 0.001) {
                 printf("Newton's method converged without producing the correct inverse:\n"
                        "%f * %f = %f (%d iterations)\n",
                        x, r0(i), prod, r1(i));
-                return -1;
+                return 1;
             }
         }
     }
@@ -675,7 +675,7 @@ int init_on_gpu_update_on_cpu_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -707,7 +707,7 @@ int init_on_cpu_update_on_gpu_test(int index) {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -756,7 +756,7 @@ int gpu_intermediate_computed_if_param_test(int index) {
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n",
                            x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -778,7 +778,7 @@ int gpu_intermediate_computed_if_param_test(int index) {
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n",
                            x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -812,7 +812,7 @@ int vectorize_predicated_rvar_test() {
             if (im(x, y) != correct) {
                 printf("im(%d, %d) = %d instead of %d\n",
                        x, y, im(x, y), correct);
-                return -1;
+                return 1;
             }
         }
     }
@@ -822,72 +822,72 @@ int vectorize_predicated_rvar_test() {
 int main(int argc, char **argv) {
     printf("Running equality inequality bound test\n");
     if (equality_inequality_bound_test(0) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running split fuse test\n");
     if (split_fuse_test(1) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running bound depend on free variable test\n");
     if (free_variable_bound_test(2) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running function call inside bound test\n");
     if (func_call_inside_bound_test(3) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running function call inside bound inline test\n");
     if (func_call_inside_bound_inline_test(4) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running two linear bounds test\n");
     if (two_linear_bounds_test(5) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running circular bound test\n");
     if (circle_bound_test(6) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running intermediate only computed if param is bigger than certain value test\n");
     if (intermediate_computed_if_param_test(7) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running tile intermediate stage depend on output bound test\n");
     if (tile_intermediate_bound_depend_on_output_test(8) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running intermediate stage depend on output bound\n");
     if (intermediate_bound_depend_on_output_test(9) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running self reference bound test\n");
     if (self_reference_bound_test(10) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running random float bound test\n");
     if (random_float_bound_test(11) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running newton's method test\n");
     if (newton_method_test() != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running vectorize predicated rvar test\n");
     if (vectorize_predicated_rvar_test() != 0) {
-        return -1;
+        return 1;
     }
 
     // Run GPU tests now if there is support for GPU.
@@ -900,17 +900,17 @@ int main(int argc, char **argv) {
 
     printf("Running initialization on gpu and update on cpu test\n");
     if (init_on_gpu_update_on_cpu_test(12) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running initialization on cpu and update on gpu test\n");
     if (init_on_cpu_update_on_gpu_test(13) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Running gpu intermediate only computed if param is bigger than certain value test\n");
     if (gpu_intermediate_computed_if_param_test(14) != 0) {
-        return -1;
+        return 1;
     }
 
     printf("Success!\n");
