@@ -43,14 +43,8 @@ bool check_expected_mallocs(const std::vector<size_t> &expected) {
     return true;
 }
 
-#ifdef _WIN32
-#define DLLEXPORT __declspec(dllexport)
-#else
-#define DLLEXPORT
-#endif
-
 // An extern stage that copies input -> output
-extern "C" DLLEXPORT int simple_buffer_copy(halide_buffer_t *in, halide_buffer_t *out) {
+extern "C" HALIDE_EXPORT_SYMBOL int simple_buffer_copy(halide_buffer_t *in, halide_buffer_t *out) {
     if (in->is_bounds_query()) {
         memcpy(in->dim, out->dim, out->dimensions * sizeof(halide_dimension_t));
     } else {
@@ -60,7 +54,7 @@ extern "C" DLLEXPORT int simple_buffer_copy(halide_buffer_t *in, halide_buffer_t
 }
 
 // An extern stage accesses the input in a non-monotonic way in the y dimension.
-extern "C" DLLEXPORT int zigzag_buffer_copy(halide_buffer_t *in, halide_buffer_t *out) {
+extern "C" HALIDE_EXPORT_SYMBOL int zigzag_buffer_copy(halide_buffer_t *in, halide_buffer_t *out) {
     if (in->is_bounds_query()) {
         memcpy(in->dim, out->dim, out->dimensions * sizeof(halide_dimension_t));
 
@@ -141,7 +135,7 @@ int main(int argc, char **argv) {
 
         size_t expected_size = 101 * 4 * sizeof(int);
         if (!check_expected_mallocs({expected_size})) {
-            return -1;
+            return 1;
         }
     }
 
@@ -160,7 +154,7 @@ int main(int argc, char **argv) {
 
         size_t expected_size = 101 * 1002 * 3 * sizeof(int);
         if (!check_expected_mallocs({expected_size})) {
-            return -1;
+            return 1;
         }
     }
 
@@ -181,7 +175,7 @@ int main(int argc, char **argv) {
 
         size_t expected_size = 101 * 3 * sizeof(int);
         if (!check_expected_mallocs({expected_size})) {
-            return -1;
+            return 1;
         }
     }
 
@@ -201,7 +195,7 @@ int main(int argc, char **argv) {
 
         if (!custom_malloc_sizes.empty()) {
             printf("There should not have been a heap allocation\n");
-            return -1;
+            return 1;
         }
 
         for (int y = 0; y < im.height(); y++) {
@@ -209,7 +203,7 @@ int main(int argc, char **argv) {
                 int correct = (2 * x) * (2 * y) + (2 * x + 1) * (2 * y + 1);
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n", x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -232,7 +226,7 @@ int main(int argc, char **argv) {
 
         if (!custom_malloc_sizes.empty()) {
             printf("There should not have been a heap allocation\n");
-            return -1;
+            return 1;
         }
 
         for (int y = 0; y < im.height(); y++) {
@@ -240,7 +234,7 @@ int main(int argc, char **argv) {
                 int correct = x * (2 * y) + (x + 3) * (2 * y + 1);
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n", x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -264,7 +258,7 @@ int main(int argc, char **argv) {
 
         size_t expected_size = 2 * 1000 * 4 * sizeof(int);
         if (!check_expected_mallocs({expected_size})) {
-            return -1;
+            return 1;
         }
 
         for (int y = 0; y < im.height(); y++) {
@@ -272,7 +266,7 @@ int main(int argc, char **argv) {
                 int correct = (2 * x) * y + (2 * x + 1) * (y + 3);
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n", x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -298,7 +292,7 @@ int main(int argc, char **argv) {
 
         size_t expected_size = 1000 * 8 * sizeof(int);
         if (!check_expected_mallocs({expected_size})) {
-            return -1;
+            return 1;
         }
 
         for (int y = 0; y < im.height(); y++) {
@@ -306,7 +300,7 @@ int main(int argc, char **argv) {
                 int correct = x * y;
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n", x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -331,7 +325,7 @@ int main(int argc, char **argv) {
 
         size_t expected_size = 2 * 1000 * 3 * sizeof(int);
         if (!check_expected_mallocs({expected_size})) {
-            return -1;
+            return 1;
         }
 
         for (int y = 0; y < im.height(); y++) {
@@ -339,7 +333,7 @@ int main(int argc, char **argv) {
                 int correct = (2 * x) * y + (2 * x + 1) * (y + 2);
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n", x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -359,7 +353,7 @@ int main(int argc, char **argv) {
 
         size_t expected_size = 1000 * 2 * sizeof(int);
         if (!check_expected_mallocs({expected_size})) {
-            return -1;
+            return 1;
         }
 
         for (int y = 0; y < im.height(); y++) {
@@ -367,7 +361,7 @@ int main(int argc, char **argv) {
                 int correct = (x) * (y / 2) + (x) * (y / 2 + 1);
                 if (im(x, y) != correct) {
                     printf("im(%d, %d) = %d instead of %d\n", x, y, im(x, y), correct);
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -391,7 +385,7 @@ int main(int argc, char **argv) {
         size_t expected_size_g = 1000 * 4 * sizeof(int) + sizeof(int);
         size_t expected_size_h = 1000 * 2 * sizeof(int) + sizeof(int);
         if (!check_expected_mallocs({expected_size_g, expected_size_h})) {
-            return -1;
+            return 1;
         }
 
         for (int y = 0; y < im.height(); y++) {
@@ -401,7 +395,7 @@ int main(int argc, char **argv) {
                 auto correct_f = [=](int x, int y) { return correct_g(x, y / 2) + correct_g(x, y / 2 + 1); };
                 if (im(x, y) != correct_f(x, y)) {
                     printf("im(%d, %d) = %d instead of %d\n", x, y, im(x, y), correct_f(x, y));
-                    return -1;
+                    return 1;
                 }
             }
         }
@@ -431,7 +425,7 @@ int main(int argc, char **argv) {
             expected_size = 101 * 3 * sizeof(int);
         }
         if (!check_expected_mallocs({expected_size})) {
-            return -1;
+            return 1;
         }
     }
 
