@@ -4,7 +4,7 @@ namespace {
 
 class ImageFromArray : public Halide::Generator<ImageFromArray> {
 public:
-    Output<Buffer<int32_t>> output{"output", 1};
+    Output<Buffer<int32_t, 1>> output{"output"};
 
     void generate() {
         // Currently the test just exercises halide_image.h.
